/*----------------------------------------------------------------------------*/
/* Xymon monitor library.                                                     */
/*                                                                            */
/* Copyright (C) 2002-2011 Henrik Storner <henrik@storner.dk>                 */
/*                                                                            */
/* This program is released under the GNU General Public License (GPL),       */
/* version 2. See the file "COPYING" for details.                             */
/*                                                                            */
/*----------------------------------------------------------------------------*/

#ifndef __LIBXYMON_H__
#define __LIBXYMON_H__

#include <stddef.h>
#include <stdio.h>
#include <time.h>


/*
 * The absolute maximum size we'll grow our buffers to accomodate an incoming message.
 * This is really just an upper bound to squash the bad guys trying to data-flood us.
 * For the backfeed queue, is further subject to MAXMSG_BFQ limits + your sysctl settings.
 */
#define MAX_XYMON_INBUFSZ (64*1024*1024)	/* 64 MB */

/*
 * The absolute maximum size we'll allow for a single message component in uncompressed
 * or un-packed format. (Handled immediately by do_message or passed to xymond_channel.)
 * Buffers for dealing with opaque data transfer, including combos/extcombos, can be larger.
 * Also subject to MAXMSG_STATUS(etc) for each particular type of message.
 */
#define MAX_XYMON_MSGSZ (32*1024*1024)		/* 32 MB */


typedef struct htnames_t {
	char *name;
	struct htnames_t *next;
} htnames_t;

typedef struct strbuffer_t {
	char *s;
	size_t used, sz;
} strbuffer_t;

#define STRBUF(buf) (buf->s)
#define STRBUFLEN(buf) (buf->used)
#define STRBUFAVAIL(buf) (buf->sz - buf->used)
#define STRBUFEND(buf) (buf->s + buf->used)
#define STRBUFSZ(buf) (buf->sz)

#define IP_ADDR_STRLEN 16

#include "version.h"
#include "config.h"
#include "osdefs.h"

#ifdef XYMONWINCLIENT
#include "strfunc.h"
#include "errormsg.h"
#include "environ.h"
#include "stackio.h"
#include "timefunc.h"
#include "memory.h"
#include "sendmsg.h"
#include "holidays.h"
#include "rbtr.h"
#include "msort.h"
#include "misc.h"
#else

/* Defines CGI URL's */
#include "cgiurls.h"
#include "links.h"

/* Generates HTML */
#include "acklog.h"
#include "eventlog.h"
#include "headfoot.h"
#include "htmllog.h"
#include "notifylog.h"
#include "acknowledgementslog.h"
#include "reportlog.h"

#include "availability.h"
#include "calc.h"
#include "cgi.h"
#include "color.h"
#include "compression.h"
#include "crondate.h"
#include "clientlocal.h"
#include "digest.h"
#include "encoding.h"
#include "environ.h"
#include "errormsg.h"
#include "files.h"
#include "xymonrrd.h"
#include "holidays.h"
#include "ipaccess.h"
#include "loadalerts.h"
#include "loadhosts.h"
#include "loadcriticalconf.h"
#include "locator.h"
#include "matching.h"
#include "md5.h"
#include "memory.h"
#include "misc.h"
#include "msort.h"
#include "netservices.h"
#include "readmib.h"
#include "rmd160c.h"
#include "run.h"
#include "sendmsg.h"
#include "sha1.h"
#include "sha2.h"
#include "sig.h"
#include "stackio.h"
#include "strfunc.h"
#include "suid.h"
#include "timefunc.h"
#include "timing.h"
#include "tree.h"
#include "url.h"
#include "webaccess.h"
#include "xxhash.h"
#include "xymond_buffer.h"
#include "xymond_ipc.h"

#endif

#endif

